@@ -1,8 +1,8 @@
 __name__ = "wallex"
-__version__ = "0.2.1"
+__version__ = "0.3.0"
 __author__ = "amiwrpremium"
 __reason__ = 'OK'
 __email__ = "amiwrpremium@gmail.com"
 __license__ = "MIT"
 __url__ = "https://github.com/amiwrpremium/wallex"
-__description__ = "Wallex cryptocurrency exchange python sdk"
+__description__ = "Wallex cryptocurrency exchange python SDK"
